@@ -79,6 +79,7 @@ import Language.Haskell.TH.Syntax
 #else
 import Language.Haskell.TH.Syntax
 #endif
+import TemplateHaskell.Compat.V0208
 import Text.Blaze (preEscapedToMarkup)
 import Text.Blaze.Html (toHtml)
 import Text.Blaze.Internal (preEscapedText)
@@ -495,7 +496,7 @@ docsToExp set scope docs = do
   case exps of
     [] -> [|return ()|]
     [x] -> return x
-    _ -> return $ DoE $ map NoBindS exps
+    _ -> return $ doE $ map NoBindS exps
 
 docToExp :: HeterocephalusSetting -> Scope -> Doc -> Q Exp
 docToExp set scope (DocForall list idents inside) = do
@@ -522,7 +523,10 @@ docToExp set scope (DocCond conds final) = do
     go (d, docs) = do
       let d' = derefToExp ((specialOrIdent, VarE 'or) : scope) d
       docs' <- docsToExp set scope docs
-      return $ TupE [d', docs']
+      return $ nonUnaryTupE [d', docs']
+      where
+        nonUnaryTupE :: [Exp] -> Exp
+        nonUnaryTupE es  = tupE es
 docToExp set scope (DocCase deref cases) = do
     let exp_ = derefToExp scope deref
     matches <- mapM toMatch cases
